"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AccordionTrigger = exports.AccordionTitleText = exports.AccordionItem = exports.AccordionIcon = exports.AccordionHeader = exports.AccordionContentText = exports.AccordionContent = exports.Accordion = void 0;
var _accordion = require("@gluestack-ui/accordion");
var _react = require("@gluestack-style/react");
var _reactNative = require("react-native");
var _htmlElements = require("@expo/html-elements");
const StyleRoot = (0, _react.styled)(_reactNative.View, {
  width: '$full',
  _icon: {
    color: '$text900'
  },
  _titleText: {
    color: '$text900'
  },
  _contentText: {
    color: '$text700'
  },
  variants: {
    size: {
      sm: {
        _titleText: {
          fontSize: '$sm',
          fontFamily: '$body',
          fontWeight: '$bold',
          lineHeight: '$sm'
        },
        _contentText: {
          fontSize: '$sm',
          fontFamily: '$body',
          fontWeight: '$normal',
          lineHeight: '$sm'
        }
      },
      md: {
        _titleText: {
          fontSize: '$md',
          fontFamily: '$body',
          fontWeight: '$bold',
          lineHeight: '$md'
        },
        _contentText: {
          fontSize: '$md',
          fontFamily: '$body',
          fontWeight: '$normal',
          lineHeight: '$md'
        }
      },
      lg: {
        _titleText: {
          fontSize: '$lg',
          fontFamily: '$body',
          fontWeight: '$bold',
          lineHeight: '$lg'
        },
        _contentText: {
          fontSize: '$lg',
          fontFamily: '$body',
          fontWeight: '$normal',
          lineHeight: '$lg'
        }
      }
    },
    variant: {
      filled: {
        backgroundColor: '$white',
        _item: {
          backgroundColor: '$background0'
        },
        shadowColor: '$background900',
        shadowOffset: {
          width: 0,
          height: 3
        },
        shadowRadius: 8,
        shadowOpacity: 0.2,
        elevation: 10
      },
      unfilled: {
        shadowColor: 'transparent',
        shadowOffset: {
          width: 0,
          height: 0
        },
        _item: {
          backgroundColor: 'transparent'
        }
      }
    }
  },
  defaultProps: {
    theme: 'light',
    size: 'md',
    variant: 'filled'
  }
}, {
  descendantStyle: ['_item', '_titleText', '_button', '_icon', '_contentText']
});
const StyledItem = (0, _react.styled)(_reactNative.View, {}, {
  ancestorStyle: ['_item']
});
// @ts-ignore
const StyledHeader = (0, _react.styled)(_reactNative.Platform.OS === 'web' ? _htmlElements.H3 : _reactNative.View, {
  mx: '$0',
  my: '$0'
});
const StyledTrigger = (0, _react.styled)(_reactNative.Pressable, {
  'width': '$full',
  'py': '$5',
  'px': '$5',
  'flexDirection': 'row',
  'justifyContent': 'space-between',
  'alignItems': 'center',
  '_web': {
    outlineWidth: 0
  },
  ':disabled': {
    opacity: 0.4,
    _web: {
      cursor: 'not-allowed'
    }
  },
  ':focusVisible': {
    bg: '$background50'
  }
}, {
  descendantStyle: ['_icon', '_titleText', '_contentText'],
  ancestorStyle: ['_button']
});
const StyledTitleText = (0, _react.styled)(_reactNative.Text, {
  flex: 1,
  textAlign: 'left'
}, {
  ancestorStyle: ['_titleText']
});
const StyledContentText = (0, _react.styled)(_reactNative.Text, {}, {
  ancestorStyle: ['_contentText']
});
const StyledIcon = (0, _react.styled)(_react.AsForwarder, {
  color: '$background800',
  // defaultProps: {
  //   size: 'md',
  // },
  variants: {
    size: {
      '2xs': {
        h: '$3',
        w: '$3',
        props: {
          // @ts-ignore
          size: 12
        }
      },
      'xs': {
        h: '$3.5',
        w: '$3.5',
        props: {
          //@ts-ignore
          size: 14
        }
      },
      'sm': {
        h: '$4',
        w: '$4',
        props: {
          //@ts-ignore
          size: 16
        }
      },
      'md': {
        h: '$4.5',
        w: '$4.5',
        props: {
          //@ts-ignore
          size: 18
        }
      },
      'lg': {
        h: '$5',
        w: '$5',
        props: {
          //@ts-ignore
          size: 20
        }
      },
      'xl': {
        h: '$6',
        w: '$6',
        props: {
          //@ts-ignore
          size: 24
        }
      }
    }
  },
  props: {
    size: 'md'
  }
}, {
  resolveProps: ['stroke', 'fill'],
  ancestorStyle: ['_icon']
}, {
  propertyTokenMap: {
    stroke: 'colors',
    fill: 'colors'
  }
});
const StyledContent = (0, _react.styled)(_reactNative.View, {
  px: '$5',
  mt: '$2',
  pb: '$5'
});
const Accordion = exports.Accordion = (0, _accordion.createAccordion)({
  Root: StyleRoot,
  Item: StyledItem,
  Header: StyledHeader,
  Trigger: StyledTrigger,
  Icon: StyledIcon,
  TitleText: StyledTitleText,
  ContentText: StyledContentText,
  Content: StyledContent
});
const AccordionItem = exports.AccordionItem = Accordion.Item;
const AccordionHeader = exports.AccordionHeader = Accordion.Header;
const AccordionTrigger = exports.AccordionTrigger = Accordion.Trigger;
const AccordionTitleText = exports.AccordionTitleText = Accordion.TitleText;
const AccordionContentText = exports.AccordionContentText = Accordion.ContentText;
const AccordionIcon = exports.AccordionIcon = Accordion.Icon;
const AccordionContent = exports.AccordionContent = Accordion.Content;
//# sourceMappingURL=index.js.map