"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AvatarImage = exports.AvatarGroup = exports.AvatarFallbackText = exports.AvatarBadge = exports.Avatar = void 0;
var _avatar = require("@gluestack-ui/avatar");
var _react = require("@gluestack-style/react");
var _reactNative = require("react-native");
const StyledRoot = (0, _react.styled)(_reactNative.View, {
  borderRadius: '$full',
  justifyContent: 'center',
  alignItems: 'center',
  position: 'relative',
  bg: '$primary600',
  variants: {
    size: {
      'xs': {
        w: '$6',
        h: '$6',
        _badge: {
          w: '$2',
          h: '$2'
        },
        _image: {
          w: '$full',
          h: '$full'
        },
        _text: {
          props: {
            size: '2xs'
          }
        }
      },
      'sm': {
        w: '$8',
        h: '$8',
        _badge: {
          w: '$2',
          h: '$2'
        },
        _image: {
          w: '$full',
          h: '$full'
        },
        _text: {
          props: {
            size: 'xs'
          }
        }
      },
      'md': {
        w: '$12',
        h: '$12',
        _badge: {
          w: '$3',
          h: '$3'
        },
        _image: {
          w: '$full',
          h: '$full'
        },
        _text: {
          props: {
            size: 'md'
          }
        }
      },
      'lg': {
        w: '$16',
        h: '$16',
        _badge: {
          w: '$4',
          h: '$4'
        },
        _image: {
          w: '$full',
          h: '$full'
        },
        _text: {
          props: {
            size: 'xl'
          }
        }
      },
      'xl': {
        w: '$24',
        h: '$24',
        _badge: {
          w: '$6',
          h: '$6'
        },
        _image: {
          w: '$full',
          h: '$full'
        },
        _text: {
          props: {
            size: '3xl'
          }
        }
      },
      '2xl': {
        w: '$32',
        h: '$32',
        _badge: {
          w: '$8',
          h: '$8'
        },
        _image: {
          w: '$full',
          h: '$full'
        },
        _text: {
          props: {
            size: '5xl'
          }
        }
      }
    }
  },
  defaultProps: {
    size: 'md'
  }
}, {
  descendantStyle: ['_badge', '_text', '_image'],
  ancestorStyle: ['_avatar']
});
const StyledBadge = (0, _react.styled)(_reactNative.View, {
  w: '$5',
  h: '$5',
  bg: '$success500',
  borderRadius: '$full',
  position: 'absolute',
  right: 0,
  bottom: 0,
  borderColor: 'white',
  borderWidth: 2
}, {
  ancestorStyle: ['_badge']
});
const StyledGroup = (0, _react.styled)(_reactNative.View, {
  flexDirection: 'row-reverse',
  position: 'relative',
  _avatar: {
    ml: -10
  }
}, {
  descendantStyle: ['_avatar']
});
const StyledImage = (0, _react.styled)(_reactNative.Image, {
  w: '$full',
  h: '$full',
  borderRadius: '$full',
  position: 'absolute'
}, {
  ancestorStyle: ['_image']
});
const StyledFallbackText = (0, _react.styled)(_reactNative.Text, {
  color: '$text0',
  fontWeight: '$semibold',
  props: {
    size: 'xl'
  },
  overflow: 'hidden',
  textTransform: 'uppercase',
  _web: {
    cursor: 'default'
  }
}, {
  ancestorStyle: ['_text']
});
const AccessbileAvatar = (0, _avatar.createAvatar)({
  Root: StyledRoot,
  Badge: StyledBadge,
  Group: StyledGroup,
  Image: StyledImage,
  FallbackText: StyledFallbackText
});
const Avatar = exports.Avatar = AccessbileAvatar;
const AvatarBadge = exports.AvatarBadge = AccessbileAvatar.Badge;
const AvatarGroup = exports.AvatarGroup = AccessbileAvatar.Group;
const AvatarImage = exports.AvatarImage = AccessbileAvatar.Image;
const AvatarFallbackText = exports.AvatarFallbackText = AccessbileAvatar.FallbackText;
//# sourceMappingURL=index.js.map