"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PopoverHeader = exports.PopoverFooter = exports.PopoverContent = exports.PopoverCloseButton = exports.PopoverBody = exports.PopoverBackdrop = exports.PopoverArrow = exports.Popover = void 0;
var _reactNative = require("react-native");
var _react = require("@gluestack-style/react");
var _animationResolver = require("@gluestack-style/animation-resolver");
var _popover = require("@gluestack-ui/popover");
const StyledRoot = (0, _react.styled)(_reactNative.View, {
  width: '$full',
  height: '$full',
  justifyContent: 'center',
  alignItems: 'center',
  variants: {
    size: {
      xs: {
        _content: {
          width: '60%',
          maxWidth: 360
        }
      },
      sm: {
        _content: {
          width: '70%',
          maxWidth: 420
        }
      },
      md: {
        _content: {
          width: '80%',
          maxWidth: 510
        }
      },
      lg: {
        _content: {
          width: '90%',
          maxWidth: 640
        }
      },
      full: {
        _content: {
          width: '100%'
        }
      }
    }
  },
  defaultProps: {
    size: 'md'
  },
  _web: {
    pointerEvents: 'box-none'
  }
}, {
  descendantStyle: ['_content']
});
const StyledArrow = (0, _react.styled)(_animationResolver.AnimatedView, {});
const StyledBackdrop = (0, _react.styled)(_animationResolver.AnimatedPressable, {
  ':initial': {
    opacity: 0
  },
  ':animate': {
    opacity: 0.5
  },
  ':exit': {
    opacity: 0
  },
  ':transition': {
    // @ts-ignore
    type: 'spring',
    damping: 18,
    stiffness: 250,
    opacity: {
      type: 'timing',
      duration: 250
    }
  },
  'position': 'absolute',
  'left': 0,
  'top': 0,
  'right': 0,
  'bottom': 0,
  'bg': '$background950',
  // @ts-ignore
  '_web': {
    cursor: 'default'
  }
});
const StyledBody = (0, _react.styled)(_reactNative.ScrollView, {
  p: '$4',
  pt: '$2'
});
const StyledCloseButton = (0, _react.styled)(_reactNative.Pressable, {
  'zIndex': 1,
  'p': '$2',
  'rounded': '$sm',
  '_icon': {
    color: '$background400'
  },
  '_text': {
    color: '$background400'
  },
  ':hover': {
    _icon: {
      color: '$background700'
    },
    _text: {
      color: '$background700'
    }
  },
  ':active': {
    _icon: {
      color: '$background900'
    },
    _text: {
      color: '$background900'
    }
  },
  ':focusVisible': {
    bg: '$background100',
    _icon: {
      color: '$background900'
    },
    _text: {
      color: '$background900'
    }
  },
  '_web': {
    outlineWidth: 0,
    cursor: 'pointer'
  }
}, {
  descendantStyle: ['_icon', '_text']
});
const StyledContent = (0, _react.styled)(_animationResolver.AnimatedView, {
  'bg': '$background50',
  'rounded': '$lg',
  'overflow': 'hidden',
  ':initial': {
    opacity: 0
  },
  ':animate': {
    opacity: 1
  },
  ':exit': {
    opacity: 0
  },
  ':transition': {
    type: 'spring',
    damping: 18,
    stiffness: 250,
    // @ts-ignore
    opacity: {
      type: 'timing',
      duration: 250
    }
  },
  'defaultProps': {
    softShadow: '3'
  }
}, {
  ancestorStyle: ['_content']
});
const StyledFooter = (0, _react.styled)(_reactNative.View, {
  p: '$4',
  flexDirection: 'row',
  justifyContent: 'flex-end',
  alignItems: 'center',
  flexWrap: 'wrap',
  borderTopWidth: 1,
  borderColor: '$border300'
});
const StyledHeader = (0, _react.styled)(_reactNative.View, {
  p: '$4',
  pb: '$2',
  justifyContent: 'space-between',
  alignItems: 'center',
  flexDirection: 'row'
});
const UIPopover = (0, _popover.createPopover)({
  Root: StyledRoot,
  Arrow: StyledArrow,
  Content: StyledContent,
  Header: StyledHeader,
  Footer: StyledFooter,
  Body: StyledBody,
  Backdrop: StyledBackdrop,
  CloseButton: StyledCloseButton,
  //@ts-ignore
  AnimatePresence: _animationResolver.AnimatePresence
});
const Popover = exports.Popover = UIPopover;
const PopoverArrow = exports.PopoverArrow = UIPopover.Arrow;
const PopoverContent = exports.PopoverContent = UIPopover.Content;
const PopoverHeader = exports.PopoverHeader = UIPopover.Header;
const PopoverFooter = exports.PopoverFooter = UIPopover.Footer;
const PopoverBody = exports.PopoverBody = UIPopover.Body;
const PopoverBackdrop = exports.PopoverBackdrop = UIPopover.Backdrop;
const PopoverCloseButton = exports.PopoverCloseButton = UIPopover.CloseButton;
//# sourceMappingURL=index.js.map