"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BorderWidthComponent = void 0;
Object.defineProperty(exports, "Box", {
  enumerable: true,
  get: function () {
    return _themed.Box;
  }
});
exports.FontWeightComponent = exports.FontSizeComponent = exports.FontFamilyComponent = exports.DefaultBreakPointsComponent = exports.ColorPaletteComponent = void 0;
Object.defineProperty(exports, "HStack", {
  enumerable: true,
  get: function () {
    return _themed.HStack;
  }
});
exports.StringBreakPointsComponent = exports.SpaceComponent = exports.ShadowsComponent = exports.RadiiComponent = exports.OpacityComponent = exports.LineHeightComponent = exports.LetterSpacingComponent = void 0;
Object.defineProperty(exports, "Text", {
  enumerable: true,
  get: function () {
    return _themed.Text;
  }
});
Object.defineProperty(exports, "VStack", {
  enumerable: true,
  get: function () {
    return _themed.VStack;
  }
});
var _react = _interopRequireWildcard(require("react"));
var _themed = require("@gluestack-ui/themed");
var _config = require("@gluestack-ui/config");
var _htmlElements = require("@expo/html-elements");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable react-native/no-inline-styles */

const colors = _config.config.tokens.colors;
const colorPalette = {
  primary: {},
  secondary: {},
  tertiary: {},
  others: {}
};
for (const colorKey in colors) {
  const category = colorKey.replace(/\d+/g, "");
  const shade = colorKey.replace(/\D+/g, "");
  if (shade === "") {
    colorPalette.others[category] = colors[colorKey];
    continue;
  }
  if (!colorPalette[category]) {
    colorPalette[category] = {};
  }
  colorPalette[category][shade] = colors[colorKey];
}
const sortedColorPalette = {};
for (const category in colorPalette) {
  if (category !== "others") {
    sortedColorPalette[category] = Object.fromEntries(Object.entries(colorPalette[category]).sort());
  }
}
sortedColorPalette.others = {
  ...colorPalette.others
};
const ColorPaletteComponent = () => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.VStack, {
    flex: 1
  }, Object.keys(sortedColorPalette).map(category => {
    return /*#__PURE__*/_react.default.createElement(_react.Fragment, {
      key: category
    }, /*#__PURE__*/_react.default.createElement(_themed.Heading, {
      mb: "$4",
      size: "md"
    }, category), /*#__PURE__*/_react.default.createElement(_themed.HStack, {
      key: category,
      w: "$full",
      mb: "$4",
      flexWrap: "wrap",
      sx: {
        _web: {
          gap: 16
        }
      }
    }, Object.keys(sortedColorPalette[category]).map(shade => {
      return /*#__PURE__*/_react.default.createElement(_themed.HStack, {
        flexBasis: "30%",
        key: shade
      }, /*#__PURE__*/_react.default.createElement(_themed.Box, {
        key: shade,
        bg: sortedColorPalette[category][shade],
        w: "$12",
        h: "$12",
        rounded: "$lg",
        mr: "$4"
      }), /*#__PURE__*/_react.default.createElement(_themed.VStack, null, /*#__PURE__*/_react.default.createElement(_themed.Text, null, category === "others" ? `${shade}` : `${category}${shade}`), /*#__PURE__*/_react.default.createElement(_themed.Text, null, sortedColorPalette[category][shade])));
    })));
  })));
};
exports.ColorPaletteComponent = ColorPaletteComponent;
const spaces = _config.config.tokens.space;
const sortedSpaceObject = spaces;

// Convert the map to an array of key-value pairs for sorting
const mapEntries = Object.entries(sortedSpaceObject);

// Sort the map entries based on the keys
mapEntries.sort(([keyA, valueA], [keyB, valueB]) => {
  // Treat 'px' as the smallest and 'full' as the largest
  // Place '0' at the top
  if (keyA === "0") return -1;
  if (keyB === "0") return 1;

  // Treat 'px' as the second smallest
  if (keyA === "px") return -1;
  if (keyB === "px") return 1;

  // Treat 'full' as the largest
  if (keyA === "full") return 1;
  if (keyB === "full") return -1;

  // Values with '%' should be grouped and sorted at the end
  const isValueAPercentage = valueA.toString().includes("%");
  const isValueBPercentage = valueB.toString().includes("%");
  if (isValueAPercentage && !isValueBPercentage) return 1;
  if (isValueBPercentage && !isValueAPercentage) return -1;

  // Group values with the same denominator and sort them
  const [numA, denomA] = keyA.split("/").map(parseFloat);
  const [numB, denomB] = keyB.split("/").map(parseFloat);
  if (!isNaN(numA) && !isNaN(denomA) && !isNaN(numB) && !isNaN(denomB)) {
    if (denomA === denomB) {
      return numA - numB;
    } else {
      return denomA - denomB; // Sort by denominator if they are different
    }
  }

  // For numeric keys, compare them as numbers
  if (!isNaN(numA) && !isNaN(numB)) {
    return numA - numB;
  }

  // For other keys, compare them as strings
  return keyA.localeCompare(keyB);
});
// const spaceElementsArray =
// Create a new Map from the sorted map entries

const SpaceComponent = () => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.VStack, null, /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    h: "$8",
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
    w: 100,
    mr: "$4"
  }, "Tokens"), /*#__PURE__*/_react.default.createElement(_themed.Text, {
    w: 100,
    mr: "$4"
  }, "Value (Pixels)"), /*#__PURE__*/_react.default.createElement(_themed.Text, null, "Representation")), mapEntries.map(([key, value]) => {
    return /*#__PURE__*/_react.default.createElement(_react.Fragment, {
      key: `${key}${value}`
    }, /*#__PURE__*/_react.default.createElement(_themed.Divider, {
      my: "$2"
    }), /*#__PURE__*/_react.default.createElement(_themed.HStack, {
      key: key,
      h: "$8",
      alignItems: "center"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      w: 100,
      mr: "$4"
    }, key), /*#__PURE__*/_react.default.createElement(_themed.Text, {
      w: 100,
      mr: "$4"
    }, value), /*#__PURE__*/_react.default.createElement(_themed.Box, {
      justifyContent: "center",
      flex: 1
    }, /*#__PURE__*/_react.default.createElement(_themed.Box, {
      bg: "$primary500",
      w: value,
      h: "$4"
    }))));
  })));
};
exports.SpaceComponent = SpaceComponent;
const opacity = _config.config.tokens.opacity;
const OpacityComponent = () => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    flexWrap: "wrap",
    sx: {
      _web: {
        gap: 16
      }
    }
  }, Object.keys(opacity).map(op => {
    return /*#__PURE__*/_react.default.createElement(_themed.Box, {
      key: opacity,
      sx: {
        _web: {
          position: "relative"
        }
      }
    }, /*#__PURE__*/_react.default.createElement(_themed.Box, {
      rounded: "$lg",
      key: op,
      bg: "$cyan400",
      w: "$16",
      h: "$16",
      opacity: opacity[op],
      justifyContent: "center",
      alignItems: "center"
    }), /*#__PURE__*/_react.default.createElement(_themed.Text, {
      opacity: 1,
      color: "$textDark800",
      position: "absolute",
      sx: {
        _web: {
          top: "50%",
          left: "50%",
          transform: "translate(-50%, -50%)"
        },
        _dark: {
          color: "white"
        }
      }
    }, op));
  })));
};
exports.OpacityComponent = OpacityComponent;
const ShadowsComponent = () => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.VStack, null, /*#__PURE__*/_react.default.createElement(_themed.Heading, {
    size: "sm",
    mb: "$4"
  }, "Hard Shadows"), /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    sx: {
      _web: {
        gap: 16
      }
    }
  }, ["1", "2", "3", "4", "5"].map(shadow => {
    return /*#__PURE__*/_react.default.createElement(_themed.Box, {
      key: shadow,
      h: "$20",
      w: "$20",
      rounded: "$lg",
      mb: "$4",
      bg: "$primary500"
      // @ts-ignore
      ,
      hardShadow: shadow,
      alignItems: "center",
      justifyContent: "center"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      color: "$white"
    }, shadow));
  })), /*#__PURE__*/_react.default.createElement(_themed.Heading, {
    size: "sm",
    mb: "$4"
  }, "Soft Shadows"), /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    sx: {
      _web: {
        gap: 16
      }
    }
  }, ["1", "2", "3", "4", "5"].map(shadow => {
    return /*#__PURE__*/_react.default.createElement(_themed.Box, {
      key: shadow,
      h: "$20",
      w: "$20",
      rounded: "$lg",
      mb: "$4",
      bg: "$primary500"
      // @ts-ignore
      ,
      softShadow: shadow,
      alignItems: "center",
      justifyContent: "center"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      color: "$white"
    }, shadow));
  }))));
};
exports.ShadowsComponent = ShadowsComponent;
const borderWidths = _config.config.tokens.borderWidths;
const BorderWidthComponent = () => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    sx: {
      _web: {
        gap: 16
      }
    }
  }, Object.keys(borderWidths).map(borderWidth => {
    return /*#__PURE__*/_react.default.createElement(_themed.Box, {
      key: borderWidth,
      h: "$20",
      w: "$20",
      mb: "$4",
      borderRadius: "$lg",
      borderColor: "$purple600"
      // @ts-ignore
      ,
      borderWidth: `$${borderWidth}`,
      justifyContent: "center",
      alignItems: "center"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      color: "$black"
    }, borderWidth));
  })));
};
exports.BorderWidthComponent = BorderWidthComponent;
const radii = _config.config.tokens.radii;
const RadiiComponent = () => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    sx: {
      _web: {
        gap: 16
      }
    },
    flexWrap: "wrap"
  }, Object.keys(radii).map(borderRadiusValue => {
    return /*#__PURE__*/_react.default.createElement(_themed.Box, {
      key: borderRadiusValue,
      h: "$20",
      w: "$20",
      mb: "$4",
      bg: "$primary500"
      // @ts-ignore
      ,
      borderRadius: `$${borderRadiusValue}`,
      justifyContent: "center",
      alignItems: "center"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      color: "$white"
    }, borderRadiusValue));
  })));
};
exports.RadiiComponent = RadiiComponent;
const DefaultBreakPointsComponent = () => {
  const breakpoints = _config.config.tokens.breakpoints;
  return /*#__PURE__*/_react.default.createElement(_htmlElements.Table, {
    style: {
      borderRadius: _config.config.tokens.radii.lg,
      backgroundColor: _config.config.tokens.colors.backgroundLight50,
      //@ts-ignore
      borderCollapse: "collapse"
    }
  }, /*#__PURE__*/_react.default.createElement(_htmlElements.THead, null, /*#__PURE__*/_react.default.createElement(_htmlElements.TR, null, /*#__PURE__*/_react.default.createElement(_htmlElements.TH, {
    style: {
      minWidth: 219,
      fontFamily: "sans-serif",
      paddingHorizontal: 24,
      paddingVertical: "auto",
      height: 64,
      color: "$textLight900",
      fontSize: _config.config.tokens.fontSizes.md,
      textAlign: "left"
    }
  }, "Prefix"), /*#__PURE__*/_react.default.createElement(_htmlElements.TH, {
    style: {
      minWidth: 219,
      fontFamily: "sans-serif",
      paddingHorizontal: 24,
      paddingVertical: "auto",
      height: 64,
      color: "$textLight900",
      fontSize: _config.config.tokens.fontSizes.md,
      textAlign: "left"
    }
  }, "BreakPoint"), /*#__PURE__*/_react.default.createElement(_htmlElements.TH, {
    style: {
      minWidth: 219,
      fontFamily: "sans-serif",
      paddingHorizontal: 24,
      paddingVertical: "auto",
      height: 64,
      color: "$textLight900",
      fontSize: _config.config.tokens.fontSizes.md,
      textAlign: "left"
    }
  }, "Description"))), /*#__PURE__*/_react.default.createElement(_htmlElements.TBody, {
    style: {
      backgroundColor: _config.config.tokens.colors.backgroundLight0
    }
  }, Object.keys(breakpoints).map(breakpoint => {
    return /*#__PURE__*/_react.default.createElement(_htmlElements.TR, {
      key: breakpoint
    }, /*#__PURE__*/_react.default.createElement(_htmlElements.TD, {
      style: {
        paddingHorizontal: 24,
        paddingVertical: "auto",
        height: 64,
        borderWidth: 0,
        borderTopWidth: 1,
        borderStyle: "solid",
        borderTopColor: _config.config.tokens.colors.borderLight300,
        fontFamily: "sans-serif",
        color: _config.config.tokens.colors.textLight900,
        fontSize: _config.config.tokens.fontSizes.sm
      }
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, null, breakpoint)), /*#__PURE__*/_react.default.createElement(_htmlElements.TD, {
      style: {
        paddingHorizontal: 24,
        paddingVertical: "auto",
        height: 64,
        borderWidth: 0,
        borderTopWidth: 1,
        borderStyle: "solid",
        borderTopColor: _config.config.tokens.colors.borderLight300,
        fontFamily: "sans-serif",
        color: _config.config.tokens.colors.textLight900,
        fontSize: _config.config.tokens.fontSizes.sm
      }
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, null, breakpoints[breakpoint])), /*#__PURE__*/_react.default.createElement(_htmlElements.TD, {
      style: {
        paddingHorizontal: 24,
        paddingVertical: "auto",
        height: 64,
        borderWidth: 0,
        borderTopWidth: 1,
        borderStyle: "solid",
        borderTopColor: _config.config.tokens.colors.borderLight300,
        fontFamily: "sans-serif",
        color: _config.config.tokens.colors.textLight900,
        fontSize: _config.config.tokens.fontSizes.sm
      }
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, null, `Viewports ${breakpoints[breakpoint]} and wider`)));
  })));
};
exports.DefaultBreakPointsComponent = DefaultBreakPointsComponent;
const StringBreakPointsComponent = () => {
  let finalBreakpointsString = "";
  const breakpoints = _config.config.tokens.breakpoints;
  for (const breakpoint in breakpoints) {
    finalBreakpointsString += `${breakpoint}, `;
  }
  return /*#__PURE__*/_react.default.createElement(_themed.Text, {
    style: {
      fontFamily: "sans-serif",
      color: _config.config.tokens.colors.textLight900,
      fontSize: _config.config.tokens.fontSizes.sm
    }
  }, finalBreakpointsString);
};
exports.StringBreakPointsComponent = StringBreakPointsComponent;
const fontSizes = _config.config.tokens.fontSizes;
const FontSizeComponent = () => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.VStack, null, /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    h: "$8",
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Tokens"), /*#__PURE__*/_react.default.createElement(_themed.Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Value"), /*#__PURE__*/_react.default.createElement(_themed.Text, {
    fontWeight: "bold"
  }, "Representation")), Object.keys(fontSizes).map(size => {
    return /*#__PURE__*/_react.default.createElement(_react.Fragment, {
      key: `${size}`
    }, /*#__PURE__*/_react.default.createElement(_themed.Divider, {
      my: "$2"
    }), /*#__PURE__*/_react.default.createElement(_themed.HStack, {
      key: size,
      alignItems: "center",
      minHeight: "$6"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      w: 100,
      mr: "$4"
    }, size), /*#__PURE__*/_react.default.createElement(_themed.Text, {
      w: 100,
      mr: "$4"
    },
    // @ts-ignore
    fontSizes[size]), /*#__PURE__*/_react.default.createElement(_themed.Box, {
      justifyContent: "center",
      height: fontSizes[size]
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      fontSize: fontSizes[size]
    }, "Hello World!"))));
  })));
};
exports.FontSizeComponent = FontSizeComponent;
const FontComponent = ({
  fontObject,
  property
}) => {
  return /*#__PURE__*/_react.default.createElement(_themed.GluestackUIProvider, {
    config: _config.config
  }, /*#__PURE__*/_react.default.createElement(_themed.VStack, null, /*#__PURE__*/_react.default.createElement(_themed.HStack, {
    h: "$8",
    alignItems: "center"
  }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Tokens"), /*#__PURE__*/_react.default.createElement(_themed.Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Value"), /*#__PURE__*/_react.default.createElement(_themed.Text, {
    fontWeight: "bold"
  }, "Representation")), Object.keys(fontObject).map(key => {
    const props = {
      [`${property}`]: fontObject[key]
    };
    return /*#__PURE__*/_react.default.createElement(_react.Fragment, {
      key: `${key}`
    }, /*#__PURE__*/_react.default.createElement(_themed.Divider, {
      my: "$2"
    }), /*#__PURE__*/_react.default.createElement(_themed.HStack, {
      key: key,
      alignItems: "center",
      minHeight: "$6"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, {
      w: 100,
      mr: "$4"
    }, key), /*#__PURE__*/_react.default.createElement(_themed.Text, {
      w: 100,
      mr: "$4"
    }, fontObject[key]), /*#__PURE__*/_react.default.createElement(_themed.Box, {
      justifyContent: "center"
    }, /*#__PURE__*/_react.default.createElement(_themed.Text, props, "Hello World!"))));
  })));
};
const FontWeightComponent = () => {
  return /*#__PURE__*/_react.default.createElement(FontComponent, {
    fontObject: _config.config.tokens.fontWeights,
    property: "fontWeight"
  });
};
exports.FontWeightComponent = FontWeightComponent;
const LineHeightComponent = () => {
  return /*#__PURE__*/_react.default.createElement(FontComponent, {
    fontObject: _config.config.tokens.lineHeights,
    property: "lineHeight"
  });
};
exports.LineHeightComponent = LineHeightComponent;
const LetterSpacingComponent = () => {
  return /*#__PURE__*/_react.default.createElement(FontComponent, {
    fontObject: _config.config.tokens.letterSpacings,
    property: "letterSpacing"
  });
};
exports.LetterSpacingComponent = LetterSpacingComponent;
const FontFamilyComponent = () => {
  return /*#__PURE__*/_react.default.createElement(FontComponent, {
    fontObject: _config.config.tokens.fonts,
    property: "fontFamily"
  });
};
exports.FontFamilyComponent = FontFamilyComponent;
//# sourceMappingURL=Component.js.map