/* eslint-disable react-native/no-inline-styles */
import React, { Fragment } from "react";
import { Text, VStack, HStack, Box, GluestackUIProvider, Heading, Divider } from "@gluestack-ui/themed";
import { config } from "@gluestack-ui/config";
import { Table, TR, TBody, TD, THead, TH } from "@expo/html-elements";
const colors = config.tokens.colors;
const colorPalette = {
  primary: {},
  secondary: {},
  tertiary: {},
  others: {}
};
for (const colorKey in colors) {
  const category = colorKey.replace(/\d+/g, "");
  const shade = colorKey.replace(/\D+/g, "");
  if (shade === "") {
    colorPalette.others[category] = colors[colorKey];
    continue;
  }
  if (!colorPalette[category]) {
    colorPalette[category] = {};
  }
  colorPalette[category][shade] = colors[colorKey];
}
const sortedColorPalette = {};
for (const category in colorPalette) {
  if (category !== "others") {
    sortedColorPalette[category] = Object.fromEntries(Object.entries(colorPalette[category]).sort());
  }
}
sortedColorPalette.others = {
  ...colorPalette.others
};
const ColorPaletteComponent = () => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(VStack, {
    flex: 1
  }, Object.keys(sortedColorPalette).map(category => {
    return /*#__PURE__*/React.createElement(Fragment, {
      key: category
    }, /*#__PURE__*/React.createElement(Heading, {
      mb: "$4",
      size: "md"
    }, category), /*#__PURE__*/React.createElement(HStack, {
      key: category,
      w: "$full",
      mb: "$4",
      flexWrap: "wrap",
      sx: {
        _web: {
          gap: 16
        }
      }
    }, Object.keys(sortedColorPalette[category]).map(shade => {
      return /*#__PURE__*/React.createElement(HStack, {
        flexBasis: "30%",
        key: shade
      }, /*#__PURE__*/React.createElement(Box, {
        key: shade,
        bg: sortedColorPalette[category][shade],
        w: "$12",
        h: "$12",
        rounded: "$lg",
        mr: "$4"
      }), /*#__PURE__*/React.createElement(VStack, null, /*#__PURE__*/React.createElement(Text, null, category === "others" ? `${shade}` : `${category}${shade}`), /*#__PURE__*/React.createElement(Text, null, sortedColorPalette[category][shade])));
    })));
  })));
};
const spaces = config.tokens.space;
const sortedSpaceObject = spaces;

// Convert the map to an array of key-value pairs for sorting
const mapEntries = Object.entries(sortedSpaceObject);

// Sort the map entries based on the keys
mapEntries.sort(([keyA, valueA], [keyB, valueB]) => {
  // Treat 'px' as the smallest and 'full' as the largest
  // Place '0' at the top
  if (keyA === "0") return -1;
  if (keyB === "0") return 1;

  // Treat 'px' as the second smallest
  if (keyA === "px") return -1;
  if (keyB === "px") return 1;

  // Treat 'full' as the largest
  if (keyA === "full") return 1;
  if (keyB === "full") return -1;

  // Values with '%' should be grouped and sorted at the end
  const isValueAPercentage = valueA.toString().includes("%");
  const isValueBPercentage = valueB.toString().includes("%");
  if (isValueAPercentage && !isValueBPercentage) return 1;
  if (isValueBPercentage && !isValueAPercentage) return -1;

  // Group values with the same denominator and sort them
  const [numA, denomA] = keyA.split("/").map(parseFloat);
  const [numB, denomB] = keyB.split("/").map(parseFloat);
  if (!isNaN(numA) && !isNaN(denomA) && !isNaN(numB) && !isNaN(denomB)) {
    if (denomA === denomB) {
      return numA - numB;
    } else {
      return denomA - denomB; // Sort by denominator if they are different
    }
  }

  // For numeric keys, compare them as numbers
  if (!isNaN(numA) && !isNaN(numB)) {
    return numA - numB;
  }

  // For other keys, compare them as strings
  return keyA.localeCompare(keyB);
});
// const spaceElementsArray =
// Create a new Map from the sorted map entries

const SpaceComponent = () => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(VStack, null, /*#__PURE__*/React.createElement(HStack, {
    h: "$8",
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Text, {
    w: 100,
    mr: "$4"
  }, "Tokens"), /*#__PURE__*/React.createElement(Text, {
    w: 100,
    mr: "$4"
  }, "Value (Pixels)"), /*#__PURE__*/React.createElement(Text, null, "Representation")), mapEntries.map(([key, value]) => {
    return /*#__PURE__*/React.createElement(Fragment, {
      key: `${key}${value}`
    }, /*#__PURE__*/React.createElement(Divider, {
      my: "$2"
    }), /*#__PURE__*/React.createElement(HStack, {
      key: key,
      h: "$8",
      alignItems: "center"
    }, /*#__PURE__*/React.createElement(Text, {
      w: 100,
      mr: "$4"
    }, key), /*#__PURE__*/React.createElement(Text, {
      w: 100,
      mr: "$4"
    }, value), /*#__PURE__*/React.createElement(Box, {
      justifyContent: "center",
      flex: 1
    }, /*#__PURE__*/React.createElement(Box, {
      bg: "$primary500",
      w: value,
      h: "$4"
    }))));
  })));
};
const opacity = config.tokens.opacity;
const OpacityComponent = () => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(HStack, {
    flexWrap: "wrap",
    sx: {
      _web: {
        gap: 16
      }
    }
  }, Object.keys(opacity).map(op => {
    return /*#__PURE__*/React.createElement(Box, {
      key: opacity,
      sx: {
        _web: {
          position: "relative"
        }
      }
    }, /*#__PURE__*/React.createElement(Box, {
      rounded: "$lg",
      key: op,
      bg: "$cyan400",
      w: "$16",
      h: "$16",
      opacity: opacity[op],
      justifyContent: "center",
      alignItems: "center"
    }), /*#__PURE__*/React.createElement(Text, {
      opacity: 1,
      color: "$textDark800",
      position: "absolute",
      sx: {
        _web: {
          top: "50%",
          left: "50%",
          transform: "translate(-50%, -50%)"
        },
        _dark: {
          color: "white"
        }
      }
    }, op));
  })));
};
const ShadowsComponent = () => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(VStack, null, /*#__PURE__*/React.createElement(Heading, {
    size: "sm",
    mb: "$4"
  }, "Hard Shadows"), /*#__PURE__*/React.createElement(HStack, {
    sx: {
      _web: {
        gap: 16
      }
    }
  }, ["1", "2", "3", "4", "5"].map(shadow => {
    return /*#__PURE__*/React.createElement(Box, {
      key: shadow,
      h: "$20",
      w: "$20",
      rounded: "$lg",
      mb: "$4",
      bg: "$primary500"
      // @ts-ignore
      ,
      hardShadow: shadow,
      alignItems: "center",
      justifyContent: "center"
    }, /*#__PURE__*/React.createElement(Text, {
      color: "$white"
    }, shadow));
  })), /*#__PURE__*/React.createElement(Heading, {
    size: "sm",
    mb: "$4"
  }, "Soft Shadows"), /*#__PURE__*/React.createElement(HStack, {
    sx: {
      _web: {
        gap: 16
      }
    }
  }, ["1", "2", "3", "4", "5"].map(shadow => {
    return /*#__PURE__*/React.createElement(Box, {
      key: shadow,
      h: "$20",
      w: "$20",
      rounded: "$lg",
      mb: "$4",
      bg: "$primary500"
      // @ts-ignore
      ,
      softShadow: shadow,
      alignItems: "center",
      justifyContent: "center"
    }, /*#__PURE__*/React.createElement(Text, {
      color: "$white"
    }, shadow));
  }))));
};
const borderWidths = config.tokens.borderWidths;
const BorderWidthComponent = () => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(HStack, {
    sx: {
      _web: {
        gap: 16
      }
    }
  }, Object.keys(borderWidths).map(borderWidth => {
    return /*#__PURE__*/React.createElement(Box, {
      key: borderWidth,
      h: "$20",
      w: "$20",
      mb: "$4",
      borderRadius: "$lg",
      borderColor: "$purple600"
      // @ts-ignore
      ,
      borderWidth: `$${borderWidth}`,
      justifyContent: "center",
      alignItems: "center"
    }, /*#__PURE__*/React.createElement(Text, {
      color: "$black"
    }, borderWidth));
  })));
};
const radii = config.tokens.radii;
const RadiiComponent = () => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(HStack, {
    sx: {
      _web: {
        gap: 16
      }
    },
    flexWrap: "wrap"
  }, Object.keys(radii).map(borderRadiusValue => {
    return /*#__PURE__*/React.createElement(Box, {
      key: borderRadiusValue,
      h: "$20",
      w: "$20",
      mb: "$4",
      bg: "$primary500"
      // @ts-ignore
      ,
      borderRadius: `$${borderRadiusValue}`,
      justifyContent: "center",
      alignItems: "center"
    }, /*#__PURE__*/React.createElement(Text, {
      color: "$white"
    }, borderRadiusValue));
  })));
};
const DefaultBreakPointsComponent = () => {
  const breakpoints = config.tokens.breakpoints;
  return /*#__PURE__*/React.createElement(Table, {
    style: {
      borderRadius: config.tokens.radii.lg,
      backgroundColor: config.tokens.colors.backgroundLight50,
      //@ts-ignore
      borderCollapse: "collapse"
    }
  }, /*#__PURE__*/React.createElement(THead, null, /*#__PURE__*/React.createElement(TR, null, /*#__PURE__*/React.createElement(TH, {
    style: {
      minWidth: 219,
      fontFamily: "sans-serif",
      paddingHorizontal: 24,
      paddingVertical: "auto",
      height: 64,
      color: "$textLight900",
      fontSize: config.tokens.fontSizes.md,
      textAlign: "left"
    }
  }, "Prefix"), /*#__PURE__*/React.createElement(TH, {
    style: {
      minWidth: 219,
      fontFamily: "sans-serif",
      paddingHorizontal: 24,
      paddingVertical: "auto",
      height: 64,
      color: "$textLight900",
      fontSize: config.tokens.fontSizes.md,
      textAlign: "left"
    }
  }, "BreakPoint"), /*#__PURE__*/React.createElement(TH, {
    style: {
      minWidth: 219,
      fontFamily: "sans-serif",
      paddingHorizontal: 24,
      paddingVertical: "auto",
      height: 64,
      color: "$textLight900",
      fontSize: config.tokens.fontSizes.md,
      textAlign: "left"
    }
  }, "Description"))), /*#__PURE__*/React.createElement(TBody, {
    style: {
      backgroundColor: config.tokens.colors.backgroundLight0
    }
  }, Object.keys(breakpoints).map(breakpoint => {
    return /*#__PURE__*/React.createElement(TR, {
      key: breakpoint
    }, /*#__PURE__*/React.createElement(TD, {
      style: {
        paddingHorizontal: 24,
        paddingVertical: "auto",
        height: 64,
        borderWidth: 0,
        borderTopWidth: 1,
        borderStyle: "solid",
        borderTopColor: config.tokens.colors.borderLight300,
        fontFamily: "sans-serif",
        color: config.tokens.colors.textLight900,
        fontSize: config.tokens.fontSizes.sm
      }
    }, /*#__PURE__*/React.createElement(Text, null, breakpoint)), /*#__PURE__*/React.createElement(TD, {
      style: {
        paddingHorizontal: 24,
        paddingVertical: "auto",
        height: 64,
        borderWidth: 0,
        borderTopWidth: 1,
        borderStyle: "solid",
        borderTopColor: config.tokens.colors.borderLight300,
        fontFamily: "sans-serif",
        color: config.tokens.colors.textLight900,
        fontSize: config.tokens.fontSizes.sm
      }
    }, /*#__PURE__*/React.createElement(Text, null, breakpoints[breakpoint])), /*#__PURE__*/React.createElement(TD, {
      style: {
        paddingHorizontal: 24,
        paddingVertical: "auto",
        height: 64,
        borderWidth: 0,
        borderTopWidth: 1,
        borderStyle: "solid",
        borderTopColor: config.tokens.colors.borderLight300,
        fontFamily: "sans-serif",
        color: config.tokens.colors.textLight900,
        fontSize: config.tokens.fontSizes.sm
      }
    }, /*#__PURE__*/React.createElement(Text, null, `Viewports ${breakpoints[breakpoint]} and wider`)));
  })));
};
const StringBreakPointsComponent = () => {
  let finalBreakpointsString = "";
  const breakpoints = config.tokens.breakpoints;
  for (const breakpoint in breakpoints) {
    finalBreakpointsString += `${breakpoint}, `;
  }
  return /*#__PURE__*/React.createElement(Text, {
    style: {
      fontFamily: "sans-serif",
      color: config.tokens.colors.textLight900,
      fontSize: config.tokens.fontSizes.sm
    }
  }, finalBreakpointsString);
};
const fontSizes = config.tokens.fontSizes;
const FontSizeComponent = () => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(VStack, null, /*#__PURE__*/React.createElement(HStack, {
    h: "$8",
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Tokens"), /*#__PURE__*/React.createElement(Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Value"), /*#__PURE__*/React.createElement(Text, {
    fontWeight: "bold"
  }, "Representation")), Object.keys(fontSizes).map(size => {
    return /*#__PURE__*/React.createElement(Fragment, {
      key: `${size}`
    }, /*#__PURE__*/React.createElement(Divider, {
      my: "$2"
    }), /*#__PURE__*/React.createElement(HStack, {
      key: size,
      alignItems: "center",
      minHeight: "$6"
    }, /*#__PURE__*/React.createElement(Text, {
      w: 100,
      mr: "$4"
    }, size), /*#__PURE__*/React.createElement(Text, {
      w: 100,
      mr: "$4"
    },
    // @ts-ignore
    fontSizes[size]), /*#__PURE__*/React.createElement(Box, {
      justifyContent: "center",
      height: fontSizes[size]
    }, /*#__PURE__*/React.createElement(Text, {
      fontSize: fontSizes[size]
    }, "Hello World!"))));
  })));
};
const FontComponent = ({
  fontObject,
  property
}) => {
  return /*#__PURE__*/React.createElement(GluestackUIProvider, {
    config: config
  }, /*#__PURE__*/React.createElement(VStack, null, /*#__PURE__*/React.createElement(HStack, {
    h: "$8",
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Tokens"), /*#__PURE__*/React.createElement(Text, {
    w: 100,
    mr: "$4",
    fontWeight: "bold"
  }, "Value"), /*#__PURE__*/React.createElement(Text, {
    fontWeight: "bold"
  }, "Representation")), Object.keys(fontObject).map(key => {
    const props = {
      [`${property}`]: fontObject[key]
    };
    return /*#__PURE__*/React.createElement(Fragment, {
      key: `${key}`
    }, /*#__PURE__*/React.createElement(Divider, {
      my: "$2"
    }), /*#__PURE__*/React.createElement(HStack, {
      key: key,
      alignItems: "center",
      minHeight: "$6"
    }, /*#__PURE__*/React.createElement(Text, {
      w: 100,
      mr: "$4"
    }, key), /*#__PURE__*/React.createElement(Text, {
      w: 100,
      mr: "$4"
    }, fontObject[key]), /*#__PURE__*/React.createElement(Box, {
      justifyContent: "center"
    }, /*#__PURE__*/React.createElement(Text, props, "Hello World!"))));
  })));
};
const FontWeightComponent = () => {
  return /*#__PURE__*/React.createElement(FontComponent, {
    fontObject: config.tokens.fontWeights,
    property: "fontWeight"
  });
};
const LineHeightComponent = () => {
  return /*#__PURE__*/React.createElement(FontComponent, {
    fontObject: config.tokens.lineHeights,
    property: "lineHeight"
  });
};
const LetterSpacingComponent = () => {
  return /*#__PURE__*/React.createElement(FontComponent, {
    fontObject: config.tokens.letterSpacings,
    property: "letterSpacing"
  });
};
const FontFamilyComponent = () => {
  return /*#__PURE__*/React.createElement(FontComponent, {
    fontObject: config.tokens.fonts,
    property: "fontFamily"
  });
};
export { ColorPaletteComponent, SpaceComponent, OpacityComponent, ShadowsComponent, BorderWidthComponent, RadiiComponent, DefaultBreakPointsComponent, StringBreakPointsComponent, FontSizeComponent, FontWeightComponent, LineHeightComponent, LetterSpacingComponent, FontFamilyComponent };
export { Text, VStack, HStack, Box };
//# sourceMappingURL=Component.js.map